@@ -21,13 +21,17 @@ def notice(msg): print(f'[{bcolors.OKGREEN + bcolors.BOLD}NOTICE{bcolors.ENDC}]
 def header(msg): print(f'[{bcolors.HEADER + bcolors.BOLD}HEADER{bcolors.ENDC}] {msg}')
 def license(msg): print(f'[{bcolors.WARNING + bcolors.BOLD}LICENSE{bcolors.ENDC}] {msg}')
 def underline(msg): print(f'{bcolors.UNDERLINE}{msg}{bcolors.ENDC}')
+def failure(msg): print(f'[{bcolors.FAIL + bcolors.BOLD}FAILURE{bcolors.ENDC}] {msg}')
 
+def print_and_log_failure(msg, error_list):
+    failure(msg)
+    error_list.append(msg)
 
 class ZippedModel:
   def __init__(self, component_name, domain, model_name, url, tar_structure, checksum=None):
     self.component_name = component_name
     self.domain         = domain.lower()
-    self.model_name     = model_name.lower()
+    self.model_name     = model_name
     self.url            = url
     self.ext = ".".join(self.url.split('/')[-1].split('.')[1:])
     self.fname = f'{domain}__{component_name}__{model_name}.{self.ext}'
@@ -37,7 +41,7 @@ class ZippedModel:
 class RemoteStorageMetadata:
   ''' Contains/gets metadata about what/where data is stored on some remote endpoint. '''
   def __init__(self, 
-      link_file, checksum_file=None, expected_suffix='.tar.gz', 
+      link_file, checksum_file=None, expected_suffix='.tar', 
       tar_structure=('domain', 'component_name', 'model_name')
     ) -> None: store_attr()
   
